@@ -3,7 +3,7 @@
 	
 	@author	Daniele Maio (b0unc3) 
 	@date	16/02/2010
-	@ver	1.0
+	@ver	0.3
 	
 */
 #include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
@@ -22,6 +22,36 @@
 
 
 
+gint
+sort_iter_compare_func (GtkTreeModel *model,
+                        GtkTreeIter  *a,
+                        GtkTreeIter  *b,
+                        gpointer      userdata)
+{
+	gchar *name1, *name2;
+	gint ret = 0;
+
+
+        gtk_tree_model_get(model, a, 0, &name1, -1);
+        gtk_tree_model_get(model, b, 0, &name2, -1);
+
+        if (name1 == NULL || name2 == NULL)
+        {
+          if (name1 == NULL && name2 == NULL)
+              ret = 0;
+
+          ret = (name1 == NULL) ? -1 : 1;
+        }
+        else
+        {
+          ret = g_utf8_collate(name1,name2);
+        }
+
+        g_free(name1);
+        g_free(name2);
+
+        return ret;
+}
 
 gchar *
 g_strreplace (gchar * string, gchar * search, gchar * replace)
@@ -41,11 +71,7 @@ g_strreplace (gchar * string, gchar * search, gchar * replace)
 void
 save_info(GtkWidget *wid, gpointer user_data)
 {
-	GKeyFile *out;
-	GError *err;
-	gsize length;
-        gchar *data;
-        GtkIconTheme	*it;
+	GtkIconTheme	*it;
         GtkIconInfo	*info;
         GConfClient* client;
         int i;
@@ -71,6 +97,8 @@ save_info(GtkWidget *wid, gpointer user_data)
 	}
 	
 	gtk_widget_set_sensitive ( GTK_WIDGET(confirm), FALSE );
+	
+	gtk_widget_destroy ( GTK_WIDGET(window) );
 
 }
 
@@ -222,11 +250,24 @@ add_apps( HildonTouchSelector *btn)
         }
         g_dir_close(d);
         
+
+//        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (btn), "--- None ---"); 
+ 
+ 	GtkTreeModel *m;
+ 	GtkTreeSortable *sortable;
+ 	       
+        m = hildon_touch_selector_get_model (HILDON_TOUCH_SELECTOR(btn),0);
+        sortable = GTK_TREE_SORTABLE(m);
+	gtk_tree_sortable_set_sort_func(sortable, NULL, sort_iter_compare_func, NULL,NULL );
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(sortable), 0, GTK_SORT_ASCENDING);
+	hildon_touch_selector_set_model ( HILDON_TOUCH_SELECTOR(btn), 0, GTK_TREE_MODEL(sortable) );
+	
+        
+            
 }
 
 osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activated)
 {
-	GtkWidget 	*window;
 	HildonProgram   *program;
 	GtkWidget 	*main_box;
 	GtkWidget	*conf_box;
@@ -268,6 +309,15 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	add_apps(HILDON_TOUCH_SELECTOR(sel2));
 	add_apps(HILDON_TOUCH_SELECTOR(sel3));
 	add_apps(HILDON_TOUCH_SELECTOR(sel4));	
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel1), 0, -1);
+        hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel1), 0);
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel2), 0, -1);
+        hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel2), 0);
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel3), 0, -1);
+        hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel3), 0);
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel4), 0, -1);
+        hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel4), 0);
+
 	
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[0]), HILDON_TOUCH_SELECTOR (sel1));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[1]), HILDON_TOUCH_SELECTOR (sel2));
