@@ -1,3 +1,11 @@
+/*
+	quick-launch header
+	
+	@author	Daniele Maio (b0unc3) 
+	@date	16/02/2010
+	@ver	0.3
+	
+*/
 #ifndef __QUICK_LAUNCH_STATUS_MENU_ITEM_H__
 #define __QUICK_LAUNCH_STATUS_MENU_ITEM_H__
 
@@ -49,6 +57,7 @@ static gchar		*bins[4];
 static GtkWidget 	*btns[4];
 static gchar 		*group_name[4] = { "first", "second", "third", "fourth" };
 static GtkWidget 	*confirm;
+static GtkWidget 	*window;
 
 
 /**/
